@@ -3,7 +3,8 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01_01';
+$VERSION = eval $VERSION;
 
 use parent 'Module::Build';
 
@@ -639,7 +640,7 @@ sub alien_create_repositories {
     }
 
     $repo->{platform} = 'src' unless defined $repo->{platform};
-    my $protocol = $repo->{protocol} || 'default';
+    $repo->{protocol} || 'default';
 
     foreach my $var (@env_overrides) {
         my $var_tail = lc substr($var, length($env_prefix));
@@ -650,7 +651,7 @@ sub alien_create_repositories {
         }
     }
 
-    push @repos, $self->alien_repository_class($protocol)->new( $repo );
+    push @repos, $self->alien_repository_class($repo->{protocol})->new( $repo );
   }
 
   # check validation, including c compiler for src type
